@@ -73,7 +73,7 @@ def add_metalines(length_ls, x_start=0, y_start=0, width=0.2 * u, height=0.22 *
 
 
 def add_metalines_shift(length_ls, x_start=0, y_start=0, width=0.2 * u, height=0.22 * u, period=0.5 * u, distance=3 * u,
-						layer_num=1, group_num=3, layer_temp=0, material="SiO2 (Glass) - Palik"
+						layer_num=1, group_num=3, layer_temp=0, material="SiO2 (Glass) - Palik",mesh_metaline_flag=False
 						):
 	"""
 	批量化放置衍射线，并返回相关参数
@@ -127,6 +127,10 @@ def add_metalines_shift(length_ls, x_start=0, y_start=0, width=0.2 * u, height=0
 			if group_count % group_num == 0:
 				length_pin = length_pin + 1
 			y = y + period  # 向y正方向放置下一个槽
+		if mesh_metaline_flag:
+			lupy.simulation.add_mesh(x_min=x - 1 * u, x_max=x + 5 * u,
+									 y_min=y_start - width / 2, y_max=y,
+									 z_min=0, z_max=height)
 		x = x + distance  # 向x正方形放置下一个层
 	x_min = x_start
 	x_max = x
